==> datadog-api-client-1.10.0.tar.gz: datadog-api-client-1.10.0/src/datadog_api_client/v1/model/service_level_objective_query.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.v1.model_utils import (
    ModelNormal,
    cached_property,
)


class ServiceLevelObjectiveQuery(ModelNormal):

    validations = {}

    @cached_property
    def openapi_types():
        return {
            "denominator": (str,),
            "numerator": (str,),
        }

    attribute_map = {
        "denominator": "denominator",
        "numerator": "numerator",
    }

    read_only_vars = {}

    def __init__(self, denominator, numerator, *args, **kwargs):
        """
        A metric SLI query. **Required if type is `metric`**. Note that Datadog only allows the sum by aggregator
        to be used because this will sum up all request counts instead of averaging them, or taking the max or
        min of all of those requests.

        :param denominator: A Datadog metric query for total (valid) events.
        :type denominator: str

        :param numerator: A Datadog metric query for good events.
        :type numerator: str
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.denominator = denominator
        self.numerator = numerator

    @classmethod
    def _from_openapi_data(cls, denominator, numerator, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(ServiceLevelObjectiveQuery, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.denominator = denominator
        self.numerator = numerator
        return self

==> datadog-api-client-1.11.0.tar.gz: datadog-api-client-1.11.0/src/datadog_api_client/v1/model/service_level_objective_query.py <==
# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class ServiceLevelObjectiveQuery(ModelNormal):
    @cached_property
    def openapi_types(_):
        return {
            "denominator": (str,),
            "numerator": (str,),
        }

    attribute_map = {
        "denominator": "denominator",
        "numerator": "numerator",
    }

    def __init__(self, denominator, numerator, *args, **kwargs):
        """
        A metric SLI query. **Required if type is `metric`**. Note that Datadog only allows the sum by aggregator
        to be used because this will sum up all request counts instead of averaging them, or taking the max or
        min of all of those requests.

        :param denominator: A Datadog metric query for total (valid) events.
        :type denominator: str

        :param numerator: A Datadog metric query for good events.
        :type numerator: str
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

        self.denominator = denominator
        self.numerator = numerator

    @classmethod
    def _from_openapi_data(cls, denominator, numerator, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(ServiceLevelObjectiveQuery, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        self.denominator = denominator
        self.numerator = numerator
        return self
